@@ -192,9 +192,11 @@ class Emulator(object):
                 try:
                     cdist_object = self.cdist_object.object_from_name(requirement)
                 except core.cdist_type.NoSuchTypeError as e:
-                    self.log.error("%s requires object %s, but type %s does not exist (definded at %s)"  % (self.cdist_object.name, requirement, e.name, self.object_source))
+                    self.log.error("%s requires object %s, but type %s does not exist. Defined at %s"  % (self.cdist_object.name, requirement, e.name, self.object_source))
+                    raise
+                except core.cdist_object.MissingObjectIdError as e:
+                    self.log.error("%s requires object %s without object id. Defined at %s"  % (self.cdist_object.name, requirement, self.object_source))
                     raise
-
 
                 self.log.debug("Recording requirement: " + requirement)
 
